@@ -502,10 +502,18 @@ class LSwitch(NVPEntity):
         self['port_isolation_enabled'] = enabled
         return self
 
-    def transport_zones(self, zones):
-        """Will set/update the transport zones that the switch is connected
+    def transport_zone(self, zone_uuid, transport_type, vlan_id=None):
+        """Sets/updates the transport zones that the switch is connected
+        to. Expects zones to be a list of dicts with keys "zone_uuid" and
+        "transport_type" set in each.
         """
-        #TODO: Soon
+        self["transport_zones"] = self.get("transport_zones") or []
+        tz = dict(zone_uuid=zone_uuid, transport_type=transport_type)
+        if vlan_id:
+            vlan = dict(transport=vlan_id)
+            tz["binding_config"] = {}
+            tz["binding_config"]["vlan_translation"] = [vlan]
+        self["transport_zones"].append(tz)
         return self
 
     def query(self):
@@ -572,7 +580,12 @@ class LSwitchPort(NVPEntity):
         pass
 
     def attachment_vif(self, vif_uuid, hypervisor=None):
-        pass
+        logger.info("Attaching VIF %s" % vif_uuid)
+        self["vif_uuid"] = vif_uuid
+        self["type"] = "VifAttachment"
+        uri = common.genuri("lswitch", self.lswitch_uuid, "lport", self.uuid,
+                            "attachment")
+        return super(LSwitchPort, self)._action('PUT', uri)
 
     def attachment_extended_network_bridge(self, tnode_uuid, bridgeid,
                                            vlan=None):
